package de.sh_edraft.data

import de.sh_edraft.config.Config
import java.net.URI
import java.net.http.HttpClient
import java.net.http.HttpRequest
import java.net.http.HttpResponse
import java.util.logging.Logger
import org.json.JSONObject

class DataService(
    private val logger: Logger,
    private val config: Config
) {

    private fun getUserJoinedMutation(id: String): String {
        return JSONObject(
            """
            {
                "query": "mutation { userJoinedGameServer { userJoined(input: { ident: \"$id\" }) { id } } }"
            }
        """.trimIndent()
        ).toString()
    }

    private fun getUserLeftMutation(id: String): String {
        return JSONObject(
            """
            {
                "query": "mutation { userJoinedGameServer { userLeft(input: { ident: \"$id\" }) { id } } }"
            }
        """.trimIndent()
        ).toString()
    }

    fun getPlayerGlobalId(name: String): String? {
        val client = HttpClient.newBuilder().build();
        val request = HttpRequest.newBuilder()
            .uri(URI.create("https://api.mojang.com/users/profiles/minecraft/$name"))
            .build();

        val response = client.send(request, HttpResponse.BodyHandlers.ofString()).body() ?: return null;
        val json = JSONObject(response)
        return json.getString("id");
    }

    fun sendJoinedPlayer(id: String) {
        val client = HttpClient.newBuilder().build();

        val request = HttpRequest.newBuilder()
            .uri(URI.create(this.config.ApiURL))
            .POST(HttpRequest.BodyPublishers.ofString(this.getUserJoinedMutation(id)))
            .header("Authorization", "API-Key ${this.config.ApiKey}")
            .header("Content-Type", "application/json")
            .build();

        val response = client.send(request, HttpResponse.BodyHandlers.ofString());
        try {
            // check if response is valid
            val joinId = JSONObject(response.body())
                .getJSONObject("data")
                .getJSONObject("userJoinedGameServer")
                .getJSONObject("userJoined")
                .getString("id")
                .toIntOrNull();
        } catch (e: Exception) {
            logger.severe(e.message);
        }
    }

    fun sendLeftPlayer(id: String) {
        val client = HttpClient.newBuilder().build();

        val request = HttpRequest.newBuilder()
            .uri(URI.create(this.config.ApiURL))
            .POST(HttpRequest.BodyPublishers.ofString(this.getUserLeftMutation(id)))
            .header("Authorization", "API-Key ${this.config.ApiKey}")
            .header("Content-Type", "application/json")
            .build();

        val response = client.send(request, HttpResponse.BodyHandlers.ofString());
        try {
            // check if response is valid
            val joinId = JSONObject(response.body())
                .getJSONObject("data")
                .getJSONObject("userJoinedGameServer")
                .getJSONObject("userJoined")
                .getString("id")
                .toIntOrNull();
        } catch (e: Exception) {
            logger.severe(e.message);
        }
    }
}